Clazz.declarePackage("JSV.api.js");
Clazz.declareInterface(JSV.api.js, "JSVAppletObject", javajs.api.js.JSAppletObject);
;//5.0.1-v7 Sat Jan 10 11:40:46 CST 2026
